--[[
	##AddOn	: CooldownIcons R(evamped)
	##Subfile 	: Options\help.lua
	##Author  : Hati ( xhatix on wowace.com )
--]]

--ScriptEnv holds every function
local CIR = CooldownIconsR

--==[Start] Database==--
local funcIndex = {
    --[1]header (wowpedia like)    - Syntax
    --[2]description                        - 
    --[3]input explanation                - or further tables ie. PlayerPower one
    --[4]return explanation            - 
    --[5]example                            - 
    spell = {
        "spell(spellName or spellID)",
        "Registers a spell-cooldown for an icon.",
        [[spellName - string, ie. "Hand of Freedom"
spellID - number, ie. 1044]],
        "none",
        [[spell("Flameshock") --in order to register all Shocks]]
    },
    item = {
        "item(itemName or itemID)",
        "Registers an item-cooldown for an icon.",
        [[itemName - string, ie. "Medallion of the Horde"
spellID - number, ie. 42122]],
        "none",
        " item(\"Medallion of the Horde\") --in order to register Medallion \n item(42122) --same as above"
    },
    flag = {
        "flag(valid_flag)",
        "Registers a specific flag for an icon.",
        "valid_flags are: "..table.concat(CIR.ScriptEnv.valid_flags.equip,", "),
        "none",
        "flag(\"trinket1\") --register trinket1 slot(upper trinket in your inventory) for cooldown",
    },
    PlayerPower = {
        "pP = PlayerPower()",
        "Returns actual value of your primary power source.",
        [[Mana         - Mage, Warlock, Priest, Shaman, Paladin, Moonkin, Druid, 
Rage             - Warrior, Bear
Energy          - Rogue, Cat
Focus            - Hunter
Rune-Power   - Death Knight]],
        "",
        [[if PlayerPower() < 15 then --if (case) then
            RangeOn() -- coloring icon red
        else --otherwise
            ResetRange() --reset forced range-coloring
        end --important otherwise lua-errors should appear
        spell("Mortal Strike") --spell registered in order to display an icon]]
    },
    TargetPower = {
        "tP = TargetPower()",
        "Returns actual percentage value of your targets primary power source.",
        [[Mana            - Mage, Warlock, Priest, Shaman, Paladin, Moonkin, Druid, 
Rage               - Warrior, Bear
Energy            - Rogue, Cat
Focus              - Hunter
Rune-Power     - Death Knight]],
        "",
        [[if TargetPower() < 13.4 then --if (case) then
            RangeOn() -- coloring icon red
        else --otherwise
            ResetRange() --reset forced range-coloring
        end --important otherwise lua-errors should appear
        spell("Mana Burn") --spell registered in order to display an icon ... no clue how much mana Mana Burn burns but 13.4 should be good enough]]
    },
    PlayerBuff = {
        "isApplied, timeRemaining = PlayerBuff(buffName [, stacks])",
        "Returns if an buff/debuff is applied to yourself, and whats it remaining time.",
         [[buffName - string of name of buff to be tracked, ie. "Maelstrom Weapon"
            stack - (optional) integer, amount of stacks present on yourself, if not entered unstackable is assumed; only matches if stack is really stack and not greater or lower]],
         [[isApplied - boolean value returning true if name matches and amount of stacks is correctly applied
             timeRemaining - float, returns amount of time buff is remaining on you. ]],
         [[if PlayerBuff("Maelstrom Weapon", 5) then --sorry currently have no example for using both return values at once
    ResetRange()
else
    RangeOn()
end
spell("Lightning Bolt")]]
    },
    TargetBuff = {
        "isApplied, timeRemaining = TargetBuff(buffName [, stacks])",
        "Returns if an buff/debuff is applied to your target, and what's it remaining time.",
        [[buffName - string, name of the buff, ie. "Flameshock"
stack - (optional) integer, amount of stacks present on your target, if no value is entered buff is assumed to have no stacks; [NYI] wayne stacks, GT/LT stack-count]],
        [[isApplied - boolean, returning true if buffName and stack-amount match
timeRemaining - float, remaining time of buff on target ]],
        [[local applied, trem = TargetBuff("Flame Shock")
if applied and trem >= 6 then --swaps icon between Earth / Flameshock depending on Flameshock debuff on target
    spell("Earth Shock")
else
    spell("Flame Shock")
end
        ]]
    },
    TargetHP = {
        "targetHP = TargetHP()",
        "Returns current percentage value of target's life.",
        "",
        [[targetHP = float, current value of target's life.]],
        [[if TargetHP < 20 then
    ResetRange()
else
    RangeOn()
end
spell("Kill Shot")
        ]]
    },
    TalentGroup = {
        "activeTalentGroup = TalentGroup()",
        "Returns integer value of your current TalentGroup.",
        "",
        "activeTalentGroup = integer, active spec/talents - dualspec, 1 = first, 2 = second",
        [[if TalentGroup() == 1 then
    if PlayerPower > 30 then 
        ResetRange()
    else
        RangeOn()
    end
    spell("Raging Blow")
else
    if PlayerPower > 15 then
        ResetRange()
    else
        RangeOn()
    end
    spell("Shield Slam")
end
        ]]
    },
    PlayerStance = {
        "activeStance = PlayerStance()",
        "Returns integer value representating current stance",
        "",
        [[activeStance - representing your current stance by integer value.
            StanceMap:
            
            
        ]],
        [[if PlayerStance() == 1 then
    spell("Mangle (Bear)()")
else
    spell("Moonfire")
end
        ]]
    },
    IsUsableSpell = {
        "isUsable, hasRessource = IsUsableSpell(spellName or spellID)",
        "Returns if spell is usable (ie. Overpower - triggered by dodge, or revenge by block) and if you have enough ressources to do so. \n More useful than PlayerRessource, as it is more generic (debuffs increasing costs and stuff)",
        [[spellName - string, ie. "Hand of Freedom"
spellID - number, ie. 1044]],
        [[isUsable - boolean, spell can be cast/used, depending on pre-requires.
hasRessource - boolean, you have enough mana/rage/focus/energy/holypower/etc. to use the spell]],
        [[local usable, haveRage = IsUsableSpell("Revenge")
        if usable and haveRage then
            ResetRange()
        else
            RangeOn()
        end
        spell("Revenge")
        ]]
    },
    GrayScaleOn = {
        "GrayscaleOn()",
        "Force the icon to be desaturated.",
        "",
        "",
        "",
    },
    GrayscaleOff = {
        "GrayscaleOff()",
        "Force the icon to be saturated.",
    },
    ResetGrayscale =  {
        "ResetGrayscale()",
        "Resets force status of grayscale.",
    },
    RangeOn ={
        "RangeOn()",
        "Force the icon to color in out-of-range color.",
    },
    RangeOff ={
        "RangeOff()",
        "Force the icon to ignore out-of-range status.",
    },
    ResetRange ={
        "ResetRange()",
        "Reset forced range status.",
    },
    SetColor = {
        "SetColor(red,yellow,blue,alpha)",
        "Force the icon to be colored in (RGBA) \n Does not ignore RangeColoring/Desaturation - so disable it for the icon or use RangeOff() & GrayscaleOff() before SetColor(r,g,b,a) (see ex.)",
    },
    ResetColor = {
        "ResetColor()",
        "Remove SetColor force.",
    },
    HasTarget = {
        "hasTarget = HasTarget()",
        "Returns boolean value depending on existance of a target.",
    },
    HasPet = {
        "hasPet = HasPet()",
        "Returns boolean value depending on existance of a pet.",
    },
    InBattleground = {
        "inBG = InBattleground()",
        "Returns a boolean value depending on currently being or not being in a battleground.",
    },
    Hide = {
        "Hide()",
        "Hides the icon. - doh! \nDon't miss to show the icon on required parts again!",
    },
    Show = {
        "Show()",
        "Show the icon. - ok that would be too easy",
    },
    Glow = {
        "Glow()",
        "Shows a glowing circle around the icon, last until canceled by UnGlow()",
    },
    UnGlow = {
        "UnGlow()",
        "Cancels Glow() glowing circle.",
    },
}
--==[End] Database==--

--==[Start] Implementation==--
local helpFormat = {
	"funcHeader", "funcDesc", "funcUsage", "funcOutput", "funcExample"
}
local helpFormatHeaders = {
    "Syntax", "Description", "Usage", "Output", "Example"
}
local function addHelpPart(kind, content, isHeader)
    local t
    if isHeader then
        t='header'
        kind =13
    else
        t='description'
    end
    return {
		name=content,
		type = t,
		order = (-12+kind),
	}
end
local function FormatHelpTable(index)
	local rt = { }
	for k,v in ipairs(funcIndex[index]) do
		if v~=nil and v~="" then
            if k~=1 then
                rt[helpFormat[k].."Expl"] = addHelpPart((2*k-1),helpFormatHeaders[k])
                rt[helpFormat[k]] = addHelpPart(2*k,v)
            else
                rt["Header"] = addHelpPart((2*k-1),index,true)
                rt[helpFormat[k].."Expl"] = addHelpPart((2*k-1),helpFormatHeaders[k],false)
                rt[helpFormat[k]] = addHelpPart(2*k,v,false)
            end
		end
	end
	return rt
end

local function GetSubHelp()
	local rt = { }
    local o = 1
	for func, _ in pairs(funcIndex) do
		rt[func] = {
			type='group', name=func, desc=funcIndex[func][2], order=o,
			args = FormatHelpTable(func),
		}
        o=o+1
	end
	return rt
end

function CIR:get_help_table()
	--[[return {
		name="Help",
		desc="CIR ingame helping files/documentation.",
		order=-1, type="group",cmdHidden=true,
		args = GetSubHelp(),
	}]]
    local rt = GetSubHelp()
    rt.mainPage = {
        type='description',
        name=[[CooldownIcons Revamped (CIR)
CIR is a cooldown-customization tool controlled by user input and various settings.

Created & Written by Hati ( xhatix on wowace.com )]],
    }
	return rt
end
